@@ -1,6 +1,6 @@
 package Dist::Zooky::Core::MakeMaker;
-BEGIN {
-  $Dist::Zooky::Core::MakeMaker::VERSION = '0.08';
+{
+  $Dist::Zooky::Core::MakeMaker::VERSION = '0.10';
 }
 
 # ABSTRACT: gather meta data for EUMM or M::I dists
@@ -33,7 +33,12 @@ sub _build_metadata {
     run ( command => $cmd, verbose => 0 );
   }
 
-  if ( -e 'MYMETA.yml' ) {
+  if ( -e 'MYMETA.json' ) {
+
+    $struct = $self->meta_from_file( 'MYMETA.json' );
+
+  }
+  elsif ( -e 'MYMETA.yml' ) {
 
     $struct = $self->meta_from_file( 'MYMETA.yml' );
 
@@ -93,7 +98,7 @@ sub _parse_makefile {
                   if $self->_vcmp( $ver, $p{$1} ) > 0;
             }
             else {
-                $p{$1} = $self->_version_to_number(version => $2);                  
+                $p{$1} = $self->_version_to_number(version => $2);
             }
         }
         next;
@@ -107,7 +112,7 @@ sub _parse_makefile {
                   if $self->_vcmp( $ver, $b{$1} ) > 0;
             }
             else {
-                $b{$1} = $self->_version_to_number(version => $2);                  
+                $b{$1} = $self->_version_to_number(version => $2);
             }
         }
         next;
@@ -121,7 +126,7 @@ sub _parse_makefile {
                   if $self->_vcmp( $ver, $c{$1} ) > 0;
             }
             else {
-                $c{$1} = $self->_version_to_number(version => $2);                  
+                $c{$1} = $self->_version_to_number(version => $2);
             }
         }
         next;
@@ -156,7 +161,7 @@ Dist::Zooky::Core::MakeMaker - gather meta data for EUMM or M::I dists
 
 =head1 VERSION
 
-version 0.08
+version 0.10
 
 =head1 AUTHOR
 
